==> python-gvm-20.8.0.tar.gz: python-gvm-20.8.0/tests/protocols/gmpv7/testcmds/test_delete_report_format.py <==
# -*- coding: utf-8 -*-
# Copyright (C) 2018 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import unittest

from gvm.errors import GvmError


class GmpDeleteReportFormatTestCase:
    def test_delete(self):
        self.gmp.delete_report_format('a1')

        self.connection.send.has_been_called_with(
            '<delete_report_format report_format_id="a1" ultimate="0"/>'
        )

    def test_delete_ultimate(self):
        self.gmp.delete_report_format('a1', ultimate=True)

        self.connection.send.has_been_called_with(
            '<delete_report_format report_format_id="a1" ultimate="1"/>'
        )

    def test_missing_id(self):
        with self.assertRaises(GvmError):
            self.gmp.delete_report_format(None)

        with self.assertRaises(GvmError):
            self.gmp.delete_report_format('')


if __name__ == '__main__':
    unittest.main()

==> python-gvm_21.1.1.orig.tar.gz: python-gvm-21.1.1/tests/protocols/gmpv7/testcmds/test_delete_report_format.py <==
# -*- coding: utf-8 -*-
# Copyright (C) 2018 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import unittest

from gvm.errors import GvmError
from gvm.protocols.gmpv7 import (
    ReportFormatType,
    get_report_format_id_from_string,
)


class GmpDeleteReportFormatTestCase:
    def test_delete(self):
        self.gmp.delete_report_format('a1')

        self.connection.send.has_been_called_with(
            '<delete_report_format report_format_id="a1" ultimate="0"/>'
        )

    def test_delete_ultimate(self):
        self.gmp.delete_report_format('a1', ultimate=True)

        self.connection.send.has_been_called_with(
            '<delete_report_format report_format_id="a1" ultimate="1"/>'
        )

    def test_missing_id(self):
        with self.assertRaises(GvmError):
            self.gmp.delete_report_format(None)

        with self.assertRaises(GvmError):
            self.gmp.delete_report_format('')

    def test_delete_with_type(self):
        self.gmp.delete_report_format(ReportFormatType.SVG)

        report_format_id = get_report_format_id_from_string('svg').value
        self.connection.send.has_been_called_with(
            '<delete_report_format '
            'report_format_id="{}" ultimate="0"/>'.format(report_format_id)
        )


if __name__ == '__main__':
    unittest.main()
